@@ -1468,4 +1468,55 @@ test_that("Build simple tfrmt with stub header",{
     "grp"
   )
 
+
+  # no stubhead if no group column
+  basic_multi_column_template2 <- tfrmt(
+    label = quo(label),
+    param = parm,
+    value = val,
+    column = c(test1,test2),
+    col_plan = col_plan(
+      label,
+      tst = col4,
+      col3,
+      col1,
+      -col5,
+      -col2
+    )
+  )
+
+  basic_example_dataset2 <- tibble::tribble(
+    ~label,    ~test1, ~test2,    ~parm, ~val,
+    "rowlabel1",  "span 1", "col1",  "value",    1,
+    "rowlabel1",  "span 1", "col2",  "value",    1,
+    "rowlabel1",        NA, "col3",  "value",    1,
+    "rowlabel1",        NA, "col4",  "value",    1,
+    "rowlabel1",        NA, "col5",  "value",    1,
+    "rowlabel2",  "span 1", "col1",  "value",    2,
+    "rowlabel2",  "span 1", "col2",  "value",    2,
+    "rowlabel2",        NA, "col3",  "value",    2,
+    "rowlabel2",        NA, "col4",  "value",    2,
+    "rowlabel2",        NA, "col5",  "value",    2,
+    "rowlabel3",  "span 1", "col1",  "value",    3,
+    "rowlabel3",  "span 1", "col2",  "value",    3,
+    "rowlabel3",        NA, "col3",  "value",    3,
+    "rowlabel3",        NA, "col4",  "value",    3,
+    "rowlabel3",        NA, "col5",  "value",    3,
+  )
+
+  suppressMessages({
+    processed_gt <- print_to_gt(tfrmt = basic_multi_column_template2, .data = basic_example_dataset2)
+  })
+
+  expect_equal(
+    processed_gt[["_boxhead"]]$column_label %>% map_chr(as.character),
+    c("label", "tst", "col3", "col1", "..tfrmt_row_grp_lbl"
+    )
+  )
+  expect_equal(
+    processed_gt[["_stubhead"]]$label,
+    NULL
+  )
+
+
 })
